package ejb.test.timer.undeploy.test;

import java.io.File;

import org.jboss.arquillian.container.test.api.Deployer;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.OverProtocol;
import org.jboss.arquillian.container.test.api.RunAsClient;
import org.jboss.arquillian.drone.api.annotation.Drone;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.test.api.ArquillianResource;
import org.jboss.shrinkwrap.api.Archive;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.shrinkwrap.resolver.api.maven.Maven;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;

import ejb.test.timer.TestTimer;

@RunWith(Arquillian.class)
@RunAsClient
public class TimerUndeployTest
{

   @Drone
   protected WebDriver driver;

   @ArquillianResource
   protected Deployer deployer;

   private static final String PATH = "http://localhost:8080/ejbtest";
   private final static String DEPLOYMENT = "ejbtest";

   private By START = By.id("form:start");
   private By CANCEL = By.id("form:cancel");

   @Deployment(name = DEPLOYMENT, managed = false, testable = false)
   @OverProtocol("Servlet 3.0")
   public static Archive<?> createDeployment()
   {

      File[] libs = Maven.resolver().loadPomFromFile("pom.xml").importCompileAndRuntimeDependencies().resolve("javax.enterprise:cdi-api", "org.jboss.spec.javax.ejb:jboss-ejb-api_3.1_spec").withTransitivity().asFile();

      return ShrinkWrap.create(WebArchive.class, "ejbtest.war").addPackage(TestTimer.class.getPackage()).
            addAsWebInfResource("web.xml", "web.xml").
            addAsWebInfResource("beans.xml", "beans.xml").
            addAsWebInfResource("faces-config.xml", "faces-config.xml").
            addAsWebResource("index.html").
            addAsWebResource("home.xhtml").
            addAsLibraries(libs);
   }

   @Test
   public void testRedeployWithRunningTimer() throws InterruptedException
   {
      deployer.deploy(DEPLOYMENT);

      driver.navigate().to(PATH);

      // start timer
      driver.findElement(START).click();
      Thread.sleep(10000l);
      deployer.undeploy(DEPLOYMENT);
      deployer.deploy(DEPLOYMENT);

      driver.navigate().to(PATH);
      // stop timer
      driver.findElement(CANCEL).click();

   }

}
